@@ -14,17 +14,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import os
 import threading
 import time
 
 from concurrent import futures
-import fixtures
 import mock
 from six.moves.urllib import parse
 from testtools import matchers
 from testtools import testcase
 
+import tooz
 import tooz.coordination
 from tooz import tests
 
@@ -38,10 +37,7 @@ def try_to_lock_job(name, coord, url, member_id):
     return lock2.acquire(blocking=False)
 
 
-class TestAPI(tests.TestCaseSkipNotImplemented):
-
-    url = os.getenv("TOOZ_TEST_URL")
-
+class TestAPI(tests.TestWithCoordinator):
     def assertRaisesAny(self, exc_classes, callable_obj, *args, **kwargs):
         checkers = [matchers.MatchesException(exc_class)
                     for exc_class in exc_classes]
@@ -49,21 +45,6 @@ class TestAPI(tests.TestCaseSkipNotImplemented):
         callable_obj = testcase.Nullary(callable_obj, *args, **kwargs)
         self.assertThat(callable_obj, matcher)
 
-    def setUp(self):
-        super(TestAPI, self).setUp()
-        if self.url is None:
-            self.skipTest("No URL set for this driver")
-        self.useFixture(fixtures.NestedTempfile())
-        self.group_id = tests.get_random_uuid()
-        self.member_id = tests.get_random_uuid()
-        self._coord = tooz.coordination.get_coordinator(self.url,
-                                                        self.member_id)
-        self._coord.start()
-
-    def tearDown(self):
-        self._coord.stop()
-        super(TestAPI, self).tearDown()
-
     def test_connection_error_bad_host(self):
         if (tooz.coordination.Characteristics.DISTRIBUTED_ACROSS_HOSTS
            not in self._coord.CHARACTERISTICS):
@@ -78,7 +59,7 @@ class TestAPI(tests.TestCaseSkipNotImplemented):
     def test_stop_first(self):
         c = tooz.coordination.get_coordinator(self.url,
                                               self.member_id)
-        self.assertRaises(tooz.coordination.ToozError,
+        self.assertRaises(tooz.ToozError,
                           c.stop)
 
     def test_create_group(self):
@@ -762,10 +743,26 @@ class TestAPI(tests.TestCaseSkipNotImplemented):
                              tests.get_random_uuid())
                 self.assertFalse(f.result())
 
+    def _do_test_get_lock_serial_locking_two_lock(self, executor,
+                                                  use_same_coord):
+        name = tests.get_random_uuid()
+        lock1 = self._coord.get_lock(name)
+        lock1.acquire()
+        lock1.release()
+        with executor(max_workers=1) as e:
+            coord = self._coord if use_same_coord else None
+            f = e.submit(try_to_lock_job, name, coord, self.url,
+                         tests.get_random_uuid())
+            self.assertTrue(f.result())
+
     def test_get_lock_concurrency_locking_two_lock_process(self):
         self._do_test_get_lock_concurrency_locking_two_lock(
             futures.ProcessPoolExecutor, False)
 
+    def test_get_lock_serial_locking_two_lock_process(self):
+        self._do_test_get_lock_serial_locking_two_lock(
+            futures.ProcessPoolExecutor, False)
+
     def test_get_lock_concurrency_locking_two_lock_thread1(self):
         self._do_test_get_lock_concurrency_locking_two_lock(
             futures.ThreadPoolExecutor, False)
